@@ -62,7 +62,7 @@ import java.util.List;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import javax.mail.internet.IDNA;
+import javax.mail.internet.idn.IDNA;
 import javax.security.auth.Subject;
 import org.apache.commons.logging.Log;
 import org.apache.jsieve.SieveException;
@@ -77,6 +77,7 @@ import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.java.Strings;
 import com.openexchange.jsieve.commands.ActionCommand;
 import com.openexchange.jsieve.commands.IfCommand;
 import com.openexchange.jsieve.commands.Rule;
@@ -186,9 +187,9 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
     private final String scriptname;
 
     private boolean useSIEVEResponseCodes = false;
-    
+
     private final Subject krbSubject;
-    
+
     /**
      * Default constructor.
      */
@@ -216,7 +217,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             sieveHandler.initializeConnection();
         }
     }
-    
+
     /**
      * {@inheritDoc}
      */
@@ -237,12 +238,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final JSONException e) {
@@ -302,12 +298,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final ParseException e) {
@@ -378,12 +369,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final ParseException e) {
@@ -479,12 +465,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+                throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final ParseException e) {
@@ -558,12 +539,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final ParseException e) {
@@ -645,7 +621,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                handleParsingException(e, credentials);
+                throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final ParseException e) {
@@ -692,12 +668,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final NumberFormatException nfe) {
@@ -738,12 +709,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final IOException e) {
                 throw OXMailfilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (final OXSieveHandlerException e) {
-                throw OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(
-                    e,
-                    e.getSieveHost(),
-                    Integer.valueOf(e.getSieveHostPort()),
-                    credentials.getRightUsername(),
-                    credentials.getContextString());
+            	throw handleParsingException(e, credentials);
             } catch (final OXSieveHandlerInvalidCredentialsException e) {
                 throw OXMailfilterExceptionCode.INVALID_CREDENTIALS.create(e, EMPTY_ARGS);
             } catch (final NumberFormatException nfe) {
@@ -916,7 +882,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
                 final ArrayList<String> header = new ArrayList<String>();
                 header.add("From");
 
-                final String[] split = vacationdomains.split(",");
+                final String[] split = Strings.splitByComma(vacationdomains);
 
                 argList.add(header);
                 argList.add(Arrays.asList(split));
@@ -1148,37 +1114,35 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
         }
         return Category.CATEGORY_ERROR;
     }
-    
+
     /**
      * The SIEVE parser is not very expressive when it comes to exceptions.
      * This method analyses an exception message and throws a more detailed
      * one if possible.
      */
-    private void handleParsingException(final OXSieveHandlerException e, final Credentials credentials) throws OXException{
+    private OXException handleParsingException(final OXSieveHandlerException e, final Credentials credentials) {
         final String message = e.toString();
 
         if(message.contains("unexpected SUBJECT")) {
-            throw OXMailfilterExceptionCode.EMPTY_MANDATORY_FIELD.create(e, "ADDRESS (probably)");
+            return OXMailfilterExceptionCode.EMPTY_MANDATORY_FIELD.create(e, "ADDRESS (probably)");
         }
         if(message.contains("address ''")) {
-            throw OXMailfilterExceptionCode.EMPTY_MANDATORY_FIELD.create(e, "ADDRESS");
+            return OXMailfilterExceptionCode.EMPTY_MANDATORY_FIELD.create(e, "ADDRESS");
         }
 
-        final OXException mex;
         if( useSIEVEResponseCodes ) {
             final SIEVEResponse.Code code = e.getSieveResponseCode();
             if( null != code ) {
-                mex = new OXException(code.getDetailnumber(), code.getMessage(), e.getSieveHost(), Integer.valueOf(e
+                return new OXException(code.getDetailnumber(), code.getMessage(), e.getSieveHost(), Integer.valueOf(e
                     .getSieveHostPort()), credentials.getRightUsername(), credentials.getContextString()).addCategory(sieveResponse2OXCategory(code)).setPrefix("MAIL_FILTER");
             } else {
-                mex = OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(e, e.getSieveHost(), Integer.valueOf(e
+                return OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(e, e.getSieveHost(), Integer.valueOf(e
                     .getSieveHostPort()), credentials.getRightUsername(), credentials.getContextString());
             }
         } else {
-            mex = OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(e, e.getSieveHost(), Integer.valueOf(e
+            return OXMailfilterExceptionCode.SIEVE_COMMUNICATION_ERROR.create(e, e.getSieveHost(), Integer.valueOf(e
                 .getSieveHostPort()), credentials.getRightUsername(), credentials.getContextString());
         }
-        throw mex;
     }
 
     private static final class Key {
